@@ -1,5 +1,7 @@
+### R code from vignette source 'soiltexture_vignette.Rnw'
+
 ###################################################
-### chunk number 1: 
+### code chunk number 1: soiltexture_vignette.Rnw:99-121
 ###################################################
 # Set a few Sweave options:
 options( 
@@ -26,7 +28,7 @@ require( "xtable" )
 
 
 ###################################################
-### chunk number 2: 
+### code chunk number 2: soiltexture_vignette.Rnw:140-161
 ###################################################
 old.wd  <- getwd() 
 
@@ -52,20 +54,20 @@ require(
 
 
 ###################################################
-### chunk number 3: COVERFIG
+### code chunk number 3: COVERFIG
 ###################################################
 TT.plot(class.p.bg.col=T,class.sys="USDA.TT",main=NA)
 
 
 ###################################################
-### chunk number 4: 
+### code chunk number 4: soiltexture_vignette.Rnw:375-415
 ###################################################
 bornes <- c(0,2,20,50,200,2e3,20e3)
 noms   <- c("Cl","FiSi","CoSi","FiSa","CoSa","Gr","St")
-txt.b  <- c("0m","2m","20m","50m","200m","2mm","2cm")
+txt.b  <- expression( 0*mu*m, 2*mu*m, 20*mu*m, 50*mu*m, 200*mu*m, 2*'mm', 2*'cm')
 
-tmp <- data.frame(bornes,noms,txt.b)
-tmp$"txt.b" <- as.character(tmp$"txt.b")
+tmp <- data.frame(bornes,noms) # ,txt.b
+#tmp$"txt.b" <- as.character(tmp$"txt.b")
 
 par(  "mar"=c(4,1,1,1)+0.1  )  #  c(bottom, left, top, right)
 
@@ -87,7 +89,7 @@ abline(v=tmp$"bornes",lty=3,lwd=c(2,4,2,4,2,4,2))
 abline(h=par("usr")[3:4],lty=1,lwd=4)
 
 mtext( 
-    text    = tmp$"txt.b"[-1], 
+    text    = txt.b[-1], 
     side    = 1, 
     line    = rep( 
         c(0.5,1.25), 
@@ -103,7 +105,7 @@ text(x=xtxt,y=rep(1,length(xtxt)),labels=tmp$"noms",cex=2)
 
 
 ###################################################
-### chunk number 5: 
+### code chunk number 5: soiltexture_vignette.Rnw:504-513
 ###################################################
 TT.plot( 
     class.sys   = "none", 
@@ -117,38 +119,44 @@ TT.plot(
 
 
 ###################################################
-### chunk number 6: 
+### code chunk number 6: soiltexture_vignette.Rnw:551-560
 ###################################################
 TT.plot( 
-    class.sys   = "FAO50.TT", 
+    class.sys   = "HYPRES.TT", 
     tri.data    = data.frame( 
         "CLAY"  = 45, 
         "SILT"  = 38, 
         "SAND"  = 17 
-    ),  #
+    ),  
     main        = NA  
-)   #
+)   
 
 
 ###################################################
-### chunk number 7: 
+### code chunk number 7: soiltexture_vignette.Rnw:565-566
 ###################################################
-tex.tbl <- TT.classes.tbl( class.sys = "FAO50.TT" ) 
+library( "xtable" ) 
+
+
+###################################################
+### code chunk number 8: soiltexture_vignette.Rnw:569-575
+###################################################
+tex.tbl <- TT.classes.tbl( class.sys = "HYPRES.TT" ) 
 xtable( 
     x       = tex.tbl[,-3],  #
-    caption = "Texture classes of the FAO system / triangle", 
+    caption = "Texture classes of the European system / triangle", 
     label   = NULL  
 )   #
 
 
 ###################################################
-### chunk number 8:  eval=FALSE
+### code chunk number 9: soiltexture_vignette.Rnw:648-649 (eval = FALSE)
 ###################################################
 ## install.packages( pkgs = "soiltexture" ) 
 
 
 ###################################################
-### chunk number 9:  eval=FALSE
+### code chunk number 10: soiltexture_vignette.Rnw:658-662 (eval = FALSE)
 ###################################################
 ## install.packages( 
 ##     pkgs  = "soiltexture", 
@@ -157,32 +165,32 @@ xtable(
 
 
 ###################################################
-### chunk number 10: 
+### code chunk number 11: soiltexture_vignette.Rnw:669-670
 ###################################################
 require( soiltexture ) 
 
 
 ###################################################
-### chunk number 11:  eval=FALSE
+### code chunk number 12: soiltexture_vignette.Rnw:678-680 (eval = FALSE)
 ###################################################
 ## detach( package:soiltexture ) 
 ## remove.packages( "soiltexture" ) 
 
 
 ###################################################
-### chunk number 12: 
+### code chunk number 13: soiltexture_vignette.Rnw:779-780
 ###################################################
 TT.plot( class.sys = "none" ) 
 
 
 ###################################################
-### chunk number 13: 
+### code chunk number 14: soiltexture_vignette.Rnw:805-806
 ###################################################
 TT.plot( class.sys = "USDA.TT" ) 
 
 
 ###################################################
-### chunk number 14: 
+### code chunk number 15: soiltexture_vignette.Rnw:820-826
 ###################################################
 tex.tbl <- TT.classes.tbl( class.sys = "USDA.TT" ) 
 xtable( 
@@ -193,30 +201,30 @@ xtable(
 
 
 ###################################################
-### chunk number 15: 
+### code chunk number 16: soiltexture_vignette.Rnw:854-855
 ###################################################
-TT.plot( class.sys = "FAO50.TT" ) 
+TT.plot( class.sys = "HYPRES.TT" ) 
 
 
 ###################################################
-### chunk number 16: 
+### code chunk number 17: soiltexture_vignette.Rnw:875-881
 ###################################################
-tex.tbl <- TT.classes.tbl( class.sys = "FAO50.TT" ) 
+tex.tbl <- TT.classes.tbl( class.sys = "HYPRES.TT" ) 
 xtable( 
     x       = tex.tbl[,-3],  #
-    caption = "Texture classes of the FAO system / triangle", 
+    caption = "Texture classes of the European system / triangle", 
     label   = NULL  
 )   #
 
 
 ###################################################
-### chunk number 17: 
+### code chunk number 18: soiltexture_vignette.Rnw:901-902
 ###################################################
 TT.plot( class.sys = "FR.AISNE.TT" ) 
 
 
 ###################################################
-### chunk number 18: 
+### code chunk number 19: soiltexture_vignette.Rnw:916-922
 ###################################################
 tex.tbl <- TT.classes.tbl( class.sys = "FR.AISNE.TT" ) 
 xtable( 
@@ -227,13 +235,13 @@ xtable(
 
 
 ###################################################
-### chunk number 19: 
+### code chunk number 20: soiltexture_vignette.Rnw:941-942
 ###################################################
 TT.plot( class.sys = "FR.GEPPA.TT" ) 
 
 
 ###################################################
-### chunk number 20: 
+### code chunk number 21: soiltexture_vignette.Rnw:953-959
 ###################################################
 tex.tbl <- TT.classes.tbl( class.sys = "FR.GEPPA.TT" ) 
 xtable( 
@@ -244,13 +252,13 @@ xtable(
 
 
 ###################################################
-### chunk number 21: 
+### code chunk number 22: soiltexture_vignette.Rnw:982-983
 ###################################################
 TT.plot( class.sys = "DE.BK94.TT" ) 
 
 
 ###################################################
-### chunk number 22: 
+### code chunk number 23: soiltexture_vignette.Rnw:994-1000
 ###################################################
 tex.tbl <- TT.classes.tbl( class.sys = "DE.BK94.TT" ) 
 xtable( 
@@ -261,13 +269,81 @@ xtable(
 
 
 ###################################################
-### chunk number 23: 
+### code chunk number 24: soiltexture_vignette.Rnw:1025-1026
+###################################################
+TT.plot( class.sys = "DE.SEA74.TT" ) 
+
+
+###################################################
+### code chunk number 25: soiltexture_vignette.Rnw:1031-1032
+###################################################
+plLim <- TT.get("DE.SEA74.TT")[["base.css.ps.lim"]][3]
+
+
+###################################################
+### code chunk number 26: soiltexture_vignette.Rnw:1043-1049
+###################################################
+tex.tbl <- TT.classes.tbl( class.sys = "DE.SEA74.TT" ) 
+xtable( 
+    x       = tex.tbl[,-3],  #
+    caption = "Texture classes of the German SEA 1974 system / triangle", 
+    label   = NULL  
+)   #
+
+
+###################################################
+### code chunk number 27: soiltexture_vignette.Rnw:1064-1070
+###################################################
+TT.plot( 
+    class.sys = "DE.SEA74.TT", 
+    blr.clock   = rep(T,3), 
+    tlr.an      = rep(60,3), 
+    blr.tx      = c("SAND","CLAY","SILT"), 
+)   #
+
+
+###################################################
+### code chunk number 28: soiltexture_vignette.Rnw:1086-1087
+###################################################
+TT.plot( class.sys = "DE.TGL85.TT" ) 
+
+
+###################################################
+### code chunk number 29: soiltexture_vignette.Rnw:1092-1093
+###################################################
+plLim <- TT.get("DE.TGL85.TT")[["base.css.ps.lim"]][3]
+
+
+###################################################
+### code chunk number 30: soiltexture_vignette.Rnw:1104-1110
+###################################################
+tex.tbl <- TT.classes.tbl( class.sys = "DE.TGL85.TT" ) 
+xtable( 
+    x       = tex.tbl[,-3],  #
+    caption = "Texture classes of the German TGL 1985 system / triangle", 
+    label   = NULL  
+)   #
+
+
+###################################################
+### code chunk number 31: soiltexture_vignette.Rnw:1121-1127
+###################################################
+TT.plot( 
+    class.sys = "DE.TGL85.TT", 
+    blr.clock   = rep(T,3), 
+    tlr.an      = rep(60,3), 
+    blr.tx      = c("SAND","CLAY","SILT"), 
+)   #
+
+
+###################################################
+### code chunk number 32: soiltexture_vignette.Rnw:1142-1143
 ###################################################
 TT.plot( class.sys = "UK.SSEW.TT" ) 
 
 
 ###################################################
-### chunk number 24: 
+### code chunk number 33: soiltexture_vignette.Rnw:1153-1159
 ###################################################
 tex.tbl <- TT.classes.tbl( class.sys = "UK.SSEW.TT" ) 
 xtable( 
@@ -278,13 +354,13 @@ xtable(
 
 
 ###################################################
-### chunk number 25: 
+### code chunk number 34: soiltexture_vignette.Rnw:1176-1177
 ###################################################
 TT.plot( class.sys = "AU.TT" ) 
 
 
 ###################################################
-### chunk number 26: 
+### code chunk number 35: soiltexture_vignette.Rnw:1188-1194
 ###################################################
 tex.tbl <- TT.classes.tbl( class.sys = "AU.TT" ) 
 xtable( 
@@ -295,13 +371,13 @@ xtable(
 
 
 ###################################################
-### chunk number 27: 
+### code chunk number 36: soiltexture_vignette.Rnw:1216-1217
 ###################################################
 TT.plot( class.sys = "BE.TT" ) 
 
 
 ###################################################
-### chunk number 28: 
+### code chunk number 37: soiltexture_vignette.Rnw:1232-1238
 ###################################################
 tex.tbl <- TT.classes.tbl( class.sys = "BE.TT" ) 
 xtable( 
@@ -312,19 +388,19 @@ xtable(
 
 
 ###################################################
-### chunk number 29: 
+### code chunk number 38: soiltexture_vignette.Rnw:1256-1257
 ###################################################
 TT.plot( class.sys = "CA.EN.TT" ) 
 
 
 ###################################################
-### chunk number 30: 
+### code chunk number 39: soiltexture_vignette.Rnw:1264-1265
 ###################################################
 TT.plot( class.sys = "CA.FR.TT" ) 
 
 
 ###################################################
-### chunk number 31: 
+### code chunk number 40: soiltexture_vignette.Rnw:1278-1284
 ###################################################
 tex.tbl <- TT.classes.tbl( class.sys = "CA.EN.TT" ) 
 xtable( 
@@ -335,7 +411,7 @@ xtable(
 
 
 ###################################################
-### chunk number 32: 
+### code chunk number 41: soiltexture_vignette.Rnw:1291-1297
 ###################################################
 tex.tbl <- TT.classes.tbl( class.sys = "CA.FR.TT" ) 
 xtable( 
@@ -346,13 +422,13 @@ xtable(
 
 
 ###################################################
-### chunk number 33: 
+### code chunk number 42: soiltexture_vignette.Rnw:1323-1324
 ###################################################
 TT.plot( class.sys = "ISSS.TT" ) 
 
 
 ###################################################
-### chunk number 34: 
+### code chunk number 43: soiltexture_vignette.Rnw:1337-1343
 ###################################################
 tex.tbl <- TT.classes.tbl( class.sys = "ISSS.TT" ) 
 xtable( 
@@ -363,13 +439,13 @@ xtable(
 
 
 ###################################################
-### chunk number 35: 
+### code chunk number 44: soiltexture_vignette.Rnw:1361-1362
 ###################################################
 TT.plot( class.sys = "ROM.TT" ) 
 
 
 ###################################################
-### chunk number 36: 
+### code chunk number 45: soiltexture_vignette.Rnw:1375-1381
 ###################################################
 tex.tbl <- TT.classes.tbl( class.sys = "ROM.TT" ) 
 xtable( 
@@ -380,7 +456,7 @@ xtable(
 
 
 ###################################################
-### chunk number 37: 
+### code chunk number 46: soiltexture_vignette.Rnw:1392-1398
 ###################################################
 TT.plot( 
     class.sys = "ROM.TT", 
@@ -391,7 +467,37 @@ TT.plot(
 
 
 ###################################################
-### chunk number 38: 
+### code chunk number 47: soiltexture_vignette.Rnw:1419-1426
+###################################################
+test <- try( TT.plot( class.sys = "PL.TT" ) ) 
+
+#   In case the posih triangle was not loaded at startup
+if( "try-error" %in% class(test) ){ 
+    plot(1,1,type="n",) 
+    text(1,1,label="Plotting failed. Polish triangle not loaded")
+}   
+
+
+###################################################
+### code chunk number 48: soiltexture_vignette.Rnw:1450-1452
+###################################################
+test <- try( plLim <- TT.get("PL.TT")[["base.css.ps.lim"]][3] ) 
+if( "try-error" %in% class(test) ){ plLim <- NA_real_ }
+
+
+###################################################
+### code chunk number 49: soiltexture_vignette.Rnw:1475-1481
+###################################################
+tex.tbl <- TT.classes.tbl( class.sys = "PL.TT" ) 
+xtable( 
+    x       = tex.tbl[,-3],  #
+    caption = "Texture classes of the Polish system / triangle", 
+    label   = NULL  
+)   #
+
+
+###################################################
+### code chunk number 50: soiltexture_vignette.Rnw:1511-1528
 ###################################################
 # Set a 2 by 2 plot matrix:
 old.par <- par(no.readonly=T)
@@ -404,7 +510,7 @@ TT.plot(
 )   #
 
 TT.plot( 
-    class.sys       = "FAO50.TT", 
+    class.sys       = "HYPRES.TT", 
     class.p.bg.col  = TRUE
 )   #
 
@@ -413,7 +519,7 @@ par(old.par)
 
 
 ###################################################
-### chunk number 39: 
+### code chunk number 51: soiltexture_vignette.Rnw:1536-1553
 ###################################################
 # Set a 2 by 2 plot matrix:
 old.par <- par(no.readonly=T)
@@ -435,7 +541,7 @@ par(old.par)
 
 
 ###################################################
-### chunk number 40: 
+### code chunk number 52: soiltexture_vignette.Rnw:1561-1578
 ###################################################
 # Set a 2 by 2 plot matrix:
 old.par <- par(no.readonly=T)
@@ -457,7 +563,7 @@ par(old.par)
 
 
 ###################################################
-### chunk number 41: 
+### code chunk number 53: soiltexture_vignette.Rnw:1585-1602
 ###################################################
 # Set a 2 by 2 plot matrix:
 old.par <- par(no.readonly=T)
@@ -479,7 +585,7 @@ par(old.par)
 
 
 ###################################################
-### chunk number 42: 
+### code chunk number 54: soiltexture_vignette.Rnw:1610-1627
 ###################################################
 # Set a 2 by 2 plot matrix:
 old.par <- par(no.readonly=T)
@@ -501,16 +607,16 @@ par(old.par)
 
 
 ###################################################
-### chunk number 43: 
+### code chunk number 55: soiltexture_vignette.Rnw:1641-1645
 ###################################################
 TT.plot( 
-    class.sys       = "FAO50.TT", 
+    class.sys       = "HYPRES.TT", 
     class.p.bg.col  = c("red","green","blue","pink","purple") 
 )   #
 
 
 ###################################################
-### chunk number 44: 
+### code chunk number 56: soiltexture_vignette.Rnw:1666-1683
 ###################################################
 # First plot the USDA texture triangle, and retrieve its 
 #   geometrical features, silently outputted by TT.plot 
@@ -532,7 +638,7 @@ TT.classes(
 
 
 ###################################################
-### chunk number 45: 
+### code chunk number 57: soiltexture_vignette.Rnw:1701-1718
 ###################################################
 # First plot the USDA texture triangle, and retrieve its 
 #   geometrical features, silently outputted by TT.plot 
@@ -554,7 +660,7 @@ TT.classes(
 
 
 ###################################################
-### chunk number 46: 
+### code chunk number 58: soiltexture_vignette.Rnw:1735-1745
 ###################################################
 # Create a dummy data frame of soil textures:
 my.text <- data.frame( 
@@ -569,17 +675,17 @@ my.text
 
 
 ###################################################
-### chunk number 47: 
+### code chunk number 59: soiltexture_vignette.Rnw:1752-1757
 ###################################################
 TT.plot( 
-    class.sys   = "FAO50.TT", 
+    class.sys   = "HYPRES.TT", 
     tri.data    = my.text, 
     main        = "Soil texture data" 
 )   #
 
 
 ###################################################
-### chunk number 48: 
+### code chunk number 60: soiltexture_vignette.Rnw:1775-1781
 ###################################################
 TT.plot( 
     class.sys   = "none", 
@@ -590,13 +696,13 @@ TT.plot(
 
 
 ###################################################
-### chunk number 49: 
+### code chunk number 61: soiltexture_vignette.Rnw:1803-1804
 ###################################################
 rand.text	<- TT.dataset(n=100,seed.val=1980042401)
 
 
 ###################################################
-### chunk number 50: 
+### code chunk number 62: soiltexture_vignette.Rnw:1808-1814
 ###################################################
 TT.plot( 
     class.sys   = "none", 
@@ -607,7 +713,7 @@ TT.plot(
 
 
 ###################################################
-### chunk number 51: 
+### code chunk number 63: soiltexture_vignette.Rnw:1825-1874
 ###################################################
 TT.plot( 
     class.sys   = "none", 
@@ -654,15 +760,14 @@ legend(
     pch         = def.pch, 
     bty         = "o", 
     bg          = NA, 
-    box.col     = NA, 
+    #box.col    = NA, # Uncomment this to remove the legend box
     text.col    = "black", 
     cex         = def.cex  
 )   #
 
 
-
 ###################################################
-### chunk number 52: 
+### code chunk number 64: soiltexture_vignette.Rnw:1921-1940
 ###################################################
 geo <- TT.geo.get() 
 #
@@ -686,7 +791,7 @@ TT.plot(
 
 
 ###################################################
-### chunk number 53: 
+### code chunk number 65: soiltexture_vignette.Rnw:1970-1988
 ###################################################
 TT.image( 
     x       = iwd.res, 
@@ -709,7 +814,7 @@ TT.plot(
 
 
 ###################################################
-### chunk number 54: 
+### code chunk number 66: soiltexture_vignette.Rnw:2023-2045
 ###################################################
 geo <- TT.geo.get()  
 #
@@ -736,7 +841,7 @@ TT.plot(
 
 
 ###################################################
-### chunk number 55: 
+### code chunk number 67: soiltexture_vignette.Rnw:2091-2113
 ###################################################
 geo <- TT.geo.get() 
 #
@@ -763,7 +868,7 @@ TT.plot(
 
 
 ###################################################
-### chunk number 56: 
+### code chunk number 68: soiltexture_vignette.Rnw:2141-2165
 ###################################################
 geo <- TT.geo.get() 
 #
@@ -792,7 +897,7 @@ TT.plot(
 
 
 ###################################################
-### chunk number 57: 
+### code chunk number 69: soiltexture_vignette.Rnw:2194-2209
 ###################################################
 # Display the USDA texture triangle:
 geo     <- TT.plot(class.sys="USDA.TT") 
@@ -812,13 +917,13 @@ TT.text(
 
 
 ###################################################
-### chunk number 58: 
+### code chunk number 70: soiltexture_vignette.Rnw:2247-2248
 ###################################################
 TT.data.test( tri.data = rand.text ) 
 
 
 ###################################################
-### chunk number 59: 
+### code chunk number 71: soiltexture_vignette.Rnw:2271-2282
 ###################################################
 res <- TT.normalise.sum( tri.data = rand.text ) 
 #
@@ -834,16 +939,16 @@ max( res[ , "residuals" ] )
 
 
 ###################################################
-### chunk number 60: 
+### code chunk number 72: soiltexture_vignette.Rnw:2310-2314
 ###################################################
 TT.points.in.classes( 
     tri.data    = my.text[1:5,], 
-    class.sys   = "FAO50.TT"  
+    class.sys   = "HYPRES.TT"  
 )   #
 
 
 ###################################################
-### chunk number 61: 
+### code chunk number 73: soiltexture_vignette.Rnw:2323-2327
 ###################################################
 TT.points.in.classes( 
     tri.data    = my.text[1:5,], 
@@ -852,38 +957,38 @@ TT.points.in.classes(
 
 
 ###################################################
-### chunk number 62: 
+### code chunk number 74: soiltexture_vignette.Rnw:2339-2344
 ###################################################
 TT.points.in.classes( 
     tri.data    = my.text[1:5,], 
-    class.sys   = "FAO50.TT", 
+    class.sys   = "HYPRES.TT", 
     PiC.type    = "l" 
 )   #
 
 
 ###################################################
-### chunk number 63: 
+### code chunk number 75: soiltexture_vignette.Rnw:2355-2360
 ###################################################
 TT.points.in.classes( 
     tri.data    = my.text[1:5,], 
-    class.sys   = "FAO50.TT", 
+    class.sys   = "HYPRES.TT", 
     PiC.type    = "t" 
 )   #
 
 
 ###################################################
-### chunk number 64: 
+### code chunk number 76: soiltexture_vignette.Rnw:2371-2377
 ###################################################
 TT.points.in.classes( 
     tri.data    = my.text[1:5,], 
-    class.sys   = "FAO50.TT", 
+    class.sys   = "HYPRES.TT", 
     PiC.type    = "t", 
     collapse    = ";"
 )   #
 
 
 ###################################################
-### chunk number 65: 
+### code chunk number 77: soiltexture_vignette.Rnw:2454-2545
 ###################################################
 tmp.cex <- 1.5
 old.par <- par(no.readonly = TRUE)
@@ -979,13 +1084,13 @@ par(old.par)
 
 
 ###################################################
-### chunk number 66: 
+### code chunk number 78: soiltexture_vignette.Rnw:2557-2558
 ###################################################
 my.text[1:5,]   
 
 
 ###################################################
-### chunk number 67: 
+### code chunk number 79: soiltexture_vignette.Rnw:2569-2574
 ###################################################
 TT.text.transf( 
 	tri.data        = my.text[1:5,],  
@@ -995,7 +1100,7 @@ TT.text.transf(
 
 
 ###################################################
-### chunk number 68: 
+### code chunk number 80: soiltexture_vignette.Rnw:2582-2588
 ###################################################
 # Copy the data.frame
 my.text.fr  <- my.text 
@@ -1006,7 +1111,7 @@ colnames(my.text.fr) <- c("ARGILE","LIMON","SABLE","CO")
 
 
 ###################################################
-### chunk number 69: 
+### code chunk number 81: soiltexture_vignette.Rnw:2595-2601
 ###################################################
 TT.text.transf( 
     tri.data        = my.text.fr[1:5,],  
@@ -1017,7 +1122,7 @@ TT.text.transf(
 
 
 ###################################################
-### chunk number 70: 
+### code chunk number 82: soiltexture_vignette.Rnw:2640-2651
 ###################################################
 # Create a random fraction between 0 and 1
 r.frac <- runif(n=dim(my.text)[1]) 
@@ -1033,7 +1138,7 @@ my.text4[1:5,]
 
 
 ###################################################
-### chunk number 71: 
+### code chunk number 83: soiltexture_vignette.Rnw:2660-2665
 ###################################################
 TT.text.transf.X( 
     tri.data        = my.text4[1:5,], 
@@ -1043,7 +1148,7 @@ TT.text.transf.X(
 
 
 ###################################################
-### chunk number 72: 
+### code chunk number 84: soiltexture_vignette.Rnw:2679-2684
 ###################################################
 TT.text.transf.X( 
     tri.data        = my.text4[1:5,], 
@@ -1053,7 +1158,7 @@ TT.text.transf.X(
 
 
 ###################################################
-### chunk number 73: 
+### code chunk number 85: soiltexture_vignette.Rnw:2698-2715
 ###################################################
 # First, plot the data without transformation:
 geo <- TT.plot( 
@@ -1075,7 +1180,7 @@ TT.points(
 
 
 ###################################################
-### chunk number 74: 
+### code chunk number 86: soiltexture_vignette.Rnw:2738-2758
 ###################################################
 # Not transformed
 geo <- TT.plot( 
@@ -1100,7 +1205,7 @@ TT.classes(
 
 
 ###################################################
-### chunk number 75: 
+### code chunk number 87: soiltexture_vignette.Rnw:2774-2792
 ###################################################
 # No transformation needed or stated
 geo <- TT.plot( 
@@ -1123,7 +1228,7 @@ TT.classes(
 
 
 ###################################################
-### chunk number 76: 
+### code chunk number 88: soiltexture_vignette.Rnw:2803-2822
 ###################################################
 # Untransformed
 geo <- TT.plot( 
@@ -1147,7 +1252,7 @@ TT.classes(
 
 
 ###################################################
-### chunk number 77: 
+### code chunk number 89: soiltexture_vignette.Rnw:2833-2851
 ###################################################
 geo <- TT.plot( 
     class.sys   = "FR.GEPPA.TT", 
@@ -1170,7 +1275,7 @@ TT.classes(
 
 
 ###################################################
-### chunk number 78: 
+### code chunk number 90: soiltexture_vignette.Rnw:2861-2881
 ###################################################
 # Not transformed
 geo <- TT.plot( 
@@ -1195,7 +1300,7 @@ TT.classes(
 
 
 ###################################################
-### chunk number 79: 
+### code chunk number 91: soiltexture_vignette.Rnw:2897-2903
 ###################################################
 TT.points.in.classes( 
     tri.data        = my.text[1:5,], 
@@ -1206,7 +1311,7 @@ TT.points.in.classes(
 
 
 ###################################################
-### chunk number 80: 
+### code chunk number 92: soiltexture_vignette.Rnw:2908-2915
 ###################################################
 TT.plot( 
     class.sys       = "USDA.TT", 
@@ -1218,7 +1323,7 @@ TT.plot(
 
 
 ###################################################
-### chunk number 81: 
+### code chunk number 93: soiltexture_vignette.Rnw:2923-2930
 ###################################################
 TT.points.in.classes( 
     tri.data        = my.text[1:5,], 
@@ -1230,7 +1335,7 @@ TT.points.in.classes(
 
 
 ###################################################
-### chunk number 82: 
+### code chunk number 94: soiltexture_vignette.Rnw:2936-2944
 ###################################################
 TT.plot( 
     class.sys       = "USDA.TT", 
@@ -1243,7 +1348,7 @@ TT.plot(
 
 
 ###################################################
-### chunk number 83: 
+### code chunk number 95: soiltexture_vignette.Rnw:2988-3002
 ###################################################
 # Create a new function, in fact the copy of TT.text.transf()
 TT.text.transf2 <- TT.text.transf
@@ -1262,7 +1367,7 @@ TT.points.in.classes(
 
 
 ###################################################
-### chunk number 84: 
+### code chunk number 96: soiltexture_vignette.Rnw:3009-3020
 ###################################################
 TT.plot( 
     class.sys       = "USDA.TT", 
@@ -1278,7 +1383,7 @@ TT.plot(
 
 
 ###################################################
-### chunk number 85: 
+### code chunk number 97: soiltexture_vignette.Rnw:3075-3080
 ###################################################
 TT.plot( 
     class.sys   = "USDA.TT", 
@@ -1288,7 +1393,7 @@ TT.plot(
 
 
 ###################################################
-### chunk number 86: 
+### code chunk number 98: soiltexture_vignette.Rnw:3105-3110
 ###################################################
 TT.plot( 
     class.sys   = "FR.AISNE.TT", 
@@ -1298,17 +1403,17 @@ TT.plot(
 
 
 ###################################################
-### chunk number 87: 
+### code chunk number 99: soiltexture_vignette.Rnw:3139-3144
 ###################################################
 TT.plot( 
-    class.sys   = "FAO50.TT", 
+    class.sys   = "HYPRES.TT", 
     blr.clock   = c(FALSE,TRUE,NA), 
-    main        = "Re-projected FAO triangle (axis directions)"  
+    main        = "Re-projected European triangle (axis directions)"  
 )   # 
 
 
 ###################################################
-### chunk number 88: 
+### code chunk number 100: soiltexture_vignette.Rnw:3165-3172
 ###################################################
 TT.plot( 
     class.sys   = "FR.GEPPA.TT", 
@@ -1320,7 +1425,7 @@ TT.plot(
 
 
 ###################################################
-### chunk number 89: 
+### code chunk number 101: soiltexture_vignette.Rnw:3190-3206
 ###################################################
 # Set a 2 by 2 plot matrix:
 old.par <- par(no.readonly=T)
@@ -1341,7 +1446,7 @@ par(old.par)
 
 
 ###################################################
-### chunk number 90: 
+### code chunk number 102: soiltexture_vignette.Rnw:3230-3247
 ###################################################
 # Set a 2 by 2 plot matrix:
 old.par <- par(no.readonly=T)
@@ -1363,7 +1468,7 @@ par(old.par)
 
 
 ###################################################
-### chunk number 91: 
+### code chunk number 103: soiltexture_vignette.Rnw:3255-3272
 ###################################################
 # Set a 2 by 2 plot matrix:
 old.par <- par(no.readonly=T)
@@ -1385,7 +1490,7 @@ par(old.par)
 
 
 ###################################################
-### chunk number 92: 
+### code chunk number 104: soiltexture_vignette.Rnw:3282-3299
 ###################################################
 # Set a 2 by 2 plot matrix:
 old.par <- par(no.readonly=T)
@@ -1407,7 +1512,7 @@ par(old.par)
 
 
 ###################################################
-### chunk number 93: 
+### code chunk number 105: soiltexture_vignette.Rnw:3307-3325
 ###################################################
 # Set a 2 by 2 plot matrix (for size):
 old.par <- par(no.readonly=T)
@@ -1430,7 +1535,7 @@ par(old.par)
 
 
 ###################################################
-### chunk number 94: 
+### code chunk number 106: soiltexture_vignette.Rnw:3336-3348
 ###################################################
 # Set a 2 by 2 plot matrix (for size):
 old.par <- par(no.readonly=T)
@@ -1447,21 +1552,21 @@ par(old.par)
 
 
 ###################################################
-### chunk number 95: 
+### code chunk number 107: soiltexture_vignette.Rnw:3373-3378
 ###################################################
 TT.plot( 
     tri.data    = my.text.fr, 
-    class.sys   = "FAO50.TT", 
+    class.sys   = "HYPRES.TT", 
     css.names   = c("ARGILE","LIMON","SABLE") 
 )   #
 
 
 ###################################################
-### chunk number 96: 
+### code chunk number 108: soiltexture_vignette.Rnw:3402-3410
 ###################################################
 TT.plot( 
     tri.data    = my.text.fr, 
-    class.sys   = "FAO50.TT", 
+    class.sys   = "HYPRES.TT", 
     css.names   = c("ARGILE","LIMON","SABLE"), 
     css.lab     = c("l'argile [%]","Le limon [%]","Le sable [%]"), 
     main        = 
@@ -1470,11 +1575,11 @@ TT.plot(
 
 
 ###################################################
-### chunk number 97: 
+### code chunk number 109: soiltexture_vignette.Rnw:3418-3430
 ###################################################
 TT.plot( 
     tri.data    = my.text.fr, 
-    class.sys   = "FAO50.TT", 
+    class.sys   = "HYPRES.TT", 
     css.names   = c("ARGILE","LIMON","SABLE"), 
     css.lab     = expression( 
         bold(sqrt('Argile'^2)~'[%]'), 
@@ -1487,7 +1592,7 @@ TT.plot(
 
 
 ###################################################
-### chunk number 98: 
+### code chunk number 110: soiltexture_vignette.Rnw:3454-3465
 ###################################################
 # Fisrt, retrieve all the data about 
 #   the USDA texture triangle
@@ -1503,10 +1608,10 @@ tmp[ !names(tmp) %in% c("tt.points","tt.polygons") ]
 
 
 ###################################################
-### chunk number 99: 
+### code chunk number 111: soiltexture_vignette.Rnw:3483-3491
 ###################################################
 # Retrieve and save the table:
-tmp2 <- TT.classes.tbl( class.sys = "FAO50.TT" ) 
+tmp2 <- TT.classes.tbl( class.sys = "HYPRES.TT" ) 
 
 # Display the first part:
 tmp2[,1:2] 
@@ -1516,22 +1621,22 @@ tmp2[,c(1,3)]
 
 
 ###################################################
-### chunk number 100: 
+### code chunk number 112: soiltexture_vignette.Rnw:3506-3507
 ###################################################
-TT.vertices.tbl( class.sys = "FAO50.TT" ) 
+TT.vertices.tbl( class.sys = "HYPRES.TT" ) 
 
 
 ###################################################
-### chunk number 101: 
+### code chunk number 113: soiltexture_vignette.Rnw:3523-3535
 ###################################################
 geo <- TT.plot( 
-    class.sys   = "FAO50.TT", 
+    class.sys   = "HYPRES.TT", 
     main        = "Vertices numbers. USDA texture triangle"
 )   # 
 
 TT.vertices.plot( 
     geo         = geo, 
-    class.sys   = "FAO50.TT", 
+    class.sys   = "HYPRES.TT", 
     col         = "red", 
     cex         = 2, 
     font        = 2  
@@ -1539,54 +1644,54 @@ TT.vertices.plot(
 
 
 ###################################################
-### chunk number 102: 
+### code chunk number 114: soiltexture_vignette.Rnw:3564-3577
 ###################################################
 # Step 1 
-FAO63 <- TT.get("FAO50.TT") 
+HYPRES63 <- TT.get("HYPRES.TT") 
 #
 # Visualize the data that will be modified
-FAO63[[ "base.css.ps.lim" ]] 
-FAO63[[ "tri.css.ps.lim" ]] 
+HYPRES63[[ "base.css.ps.lim" ]] 
+HYPRES63[[ "tri.css.ps.lim" ]] 
 #
 # Step 2 
-FAO63[[ "base.css.ps.lim" ]][3] <- 63 
-FAO63[[ "tri.css.ps.lim" ]][3]  <- 63 
+HYPRES63[[ "base.css.ps.lim" ]][3] <- 63 
+HYPRES63[[ "tri.css.ps.lim" ]][3]  <- 63 
 #
 # Step 3: Load the new texture triangle
-TT.add( "FAO63.TT" = FAO63 ) 
+TT.add( "HYPRES63.TT" = HYPRES63 ) 
 
 
 ###################################################
-### chunk number 103: 
+### code chunk number 115: soiltexture_vignette.Rnw:3585-3589
 ###################################################
 TT.plot( 
-    class.sys   = "FAO63.TT", 
-    main        = "Modified FAO soil texture triangle"
+    class.sys   = "HYPRES63.TT", 
+    main        = "Modified European soil texture triangle"
 )   # 
 
 
 ###################################################
-### chunk number 104: 
+### code chunk number 116: soiltexture_vignette.Rnw:3600-3620
 ###################################################
-# Get the definition of the FAO50 texture triangle
-FAO50 <- TT.get( "FAO50.TT" ) 
+# Get the definition of the HYPRES texture triangle
+HYPRES <- TT.get( "HYPRES.TT" ) 
 #
 # Check its class (list) 
-class( FAO50 ) 
+class( HYPRES ) 
 #
 # Check its parameters names 
-names( FAO50 ) 
+names( HYPRES ) 
 #
 # Check its parameters class 
-for( i in 1:length(FAO50) )
-{   #
+for( i in 1:length(HYPRES) )
+{   
     print( 
         paste( 
-            names( FAO50 )[i], 
-            class( FAO50[[i]] ), 
+            names( HYPRES )[i], 
+            class( HYPRES[[i]] ), 
             sep = ": "
-        )   #
-    )   # 
-}   #
+        )   
+    )    
+}   
 
 
