@@ -2,11 +2,11 @@ require( soiltexture )
 
 # ::: Texture triangles without data
 
-# :: Base plot (FAO triangle) 
+# :: Base plot (HYPRES / European Soil Map triangle) 
 TT.plot() 
 
 # same as
-TT.plot( class.sys = "FAO50.TT" ) 
+TT.plot( class.sys = "HYPRES.TT" ) 
 
 # :: Same plot, but with USDA texture triangle 
 TT.plot( class.sys = "USDA.TT" ) 
@@ -55,7 +55,7 @@ TT.plot(
 # ::: Test all the texture triangles
 
 TT.plot( class.sys = "none" )           # no classification 
-TT.plot( class.sys = "FAO50.TT" )       # FAO 
+TT.plot( class.sys = "HYPRES.TT" )      # HYPRES / European Soil Map 
 TT.plot( class.sys = "USDA.TT" )        # USDA 
 TT.plot( class.sys = "FR.AISNE.TT" )    # French Aisne 
 TT.plot( class.sys = "FR.GEPPA.TT" )    # French GEPPA 
@@ -64,10 +64,10 @@ TT.plot( class.sys = "UK.SSEW.TT" )     # UK
 TT.plot( class.sys = "BE.TT" )          # Belgium 
 TT.plot( class.sys = "CA.FR.TT" )       # Canada (fr) 
 TT.plot( class.sys = "CA.EN.TT" )       # Canada (en) 
-TT.plot( class.sys = "AU.TT" )          # Australian 
+TT.plot( class.sys = "AU2.TT" )         # Australian 
 TT.plot( class.sys = "ISSS.TT" )        # ISSS 
 TT.plot( class.sys = "ROM.TT" )         # Romanian 
-TT.plot( class.sys = "PL.TT" )          # Polish 
+try( TT.plot( class.sys = "PL.TT" ) )   # Polish 
 TT.plot( class.sys = "DE.SEA74.TT" )    # German SEA 1974 
 TT.plot( class.sys = "DE.TGL85.TT" )    # German TGL 1985 
 
@@ -83,5 +83,5 @@ TT.plot( class.sys = "USDA.TT", lang = "nl" )  #  Dutch
 TT.plot( class.sys = "USDA.TT", lang = "fl" )  #  Dutch (Belgian) / Flemmish 
 TT.plot( class.sys = "USDA.TT", lang = "se" )  #  Swedish 
 TT.plot( class.sys = "USDA.TT", lang = "ro" )  #  Romanian 
-TT.plot( class.sys = "USDA.TT", lang = "pl" )  #  Polish 
+try( TT.plot( class.sys = "USDA.TT", lang = "pl" ) ) #  Polish 
 
